# 🏫 SAGE Education - Institutional Management / ERP

**Version:** 1.0.x  
**Module:** Akademy Dashboard  
**Developer:** Zacarias Juliano Capingala *(Homem Marketing)*  

---

## 📘 About the Project

**SAGE Education** is a ***free and open-source*** project for ***educators, educational institutions, and governments***.
It provides the functionality of **Academic Management System (AMS), School Management System (SMS), and Educational Information System (EIS)**.
Its ***modular, scalable, and secure*** design allows it to be implemented in many different scenarios: from **small schools** and **training centers** to **large national public education systems**.

SAGE Education has a growing, committed, and friendly community that brings together the best in the fields of ***educational sciences, pedagogy, educational technology, and computer science***.
No matter where in the world you live, we are passionate about upholding education and educational technology as a non-negotiable human right.

We hope you find **SAGE Education** motivating and inspiring, and we look forward to having you as part of the team.

---

## ⚙️ Akademy Dashboard Module

The **Akademy Module Base (Dashboard)** is a complementary module responsible for **centralizing the functionalities** of all **Akademy** modules, offering a simple and practical menu for **Pedagogical Management**, **Administrative and Human Resources Management**, **Financial and Accounting Management**, and **Administration**, in addition to other resources of SAGE Edu.

---

## 🌐 Homepage

**Website:** [comunidadedosaber.ao](https://comunidadedosaber.ao)  
**E-mail:** [comunidadedsaber@gmail.com](mailto:comunidadedsaber@gmail.com)

---


## 🌐 Homepage

**Website:** [comunidadedosaber.ao](https://comunidadedosaber.ao)  
**E-mail:** [comercial@comunidadedosaber.ao](mailto:comercial@comunidadedosaber.ao)

---

## 💬 Technical Support

If you encounter any errors or require technical support, please contact us through the channels below:

- 📧 **E-mail:** [suporte@comunidadedosaber.ao](mailto:suporte@comunidadedosaber.ao)
- 💬 **WhatsApp:** [+244 955 868 110](https://wa.me/244955868110)



